local f = CreateFrame("Frame")

local defaults = {
    hideRealm = true,
	hideRealmParty = true,
	hideRealmNP = false,
    hideName = false,
	hideNameParty = false,
    hideRole = false,
	hideRoleParty = false,
    hideRaidMan = false,
    hideNameArena = false,
	hideNameArenaFriendly = false,
}

function f:OnEvent(event, addOnName)
    if addOnName == "HideRealmNames" then
        HideRealmNamesDB = HideRealmNamesDB or CopyTable(defaults)
        self.db = HideRealmNamesDB
        self:InitializeOptions()

        -- Hide players realm on raid frame
        if self.db.hideRealm then
            hooksecurefunc("CompactUnitFrame_UpdateName", function(frame)
                if frame and not frame:IsForbidden() then
                    local frame_name = frame:GetName()
                    if frame_name and (frame_name:match("^PartyMemberFrame%d") or frame_name:match("^CompactRaidFrame%d") or frame_name:match("^CompactRaidGroup%dMember%d") or frame_name:match("^CompactPartyFrameMember%d")) and frame.unit and frame.name then
                        if UnitIsPlayer(frame.unit) then
                            local unit_name = GetUnitName(frame.unit, true)
                            if unit_name then
                                frame.name:SetText(unit_name:match("[^-]+"))
                            end
                        end
                    end
                end
            end)
        end

		if self.db.hideRealmParty then
			local buildVersion = select(4, GetBuildInfo())
			if buildVersion >= 100000 then --Dragonflight
				hooksecurefunc("UnitFrame_Update", function(frame)
					for frame in PartyFrame.PartyMemberFramePool:EnumerateActive() do
						local unit_name = GetUnitName(frame.unit, true)
						if unit_name then
							frame.name:SetText(unit_name:match("[^-]+"))
						end
					end
				end)
			elseif buildVersion < 39999 then --Classic
				hooksecurefunc("UnitFrame_Update",function(frame)
					if frame and not frame:IsForbidden() then
						local frame_name = frame:GetName()
						if frame_name and frame_name:match("^PartyMemberFrame%d") and frame.unit and frame.name then
							local unit_name = GetUnitName(frame.unit,true)
							if unit_name then
								frame.name:SetText(unit_name:match("[^-]+"))
							end
						end
					end
				end)
			end
		end

		if self.db.hideRealmNP then
			hooksecurefunc("CompactUnitFrame_UpdateName", function(frame)
				local isInInstance, instanceType = IsInInstance()
				if not isInInstance or instanceType == "none" and ShouldShowName(frame) then
					if frame.optionTable.colorNameBySelection then
						frame.name:SetText(GetUnitName(frame.unit))
					end
				end
			end)
		end		

        -- Hide player names on raid frame
        if self.db.hideName then
            DefaultCompactUnitFrameOptions.displayName = false
        end

		if self.db.hideNameParty then
			local buildVersion = select(4, GetBuildInfo())
			if buildVersion >= 100000 then
				for frame in PartyFrame.PartyMemberFramePool:EnumerateActive() do
					frame.Name:Hide()
					frame.PartyMemberOverlay.RoleIcon:Hide()			
				end
			elseif buildVersion < 39999 then
				for i = 1, 4 do 
					_G["PartyMemberFrame"..i.."Name"]:Hide()
				end
			end
		end
		

        -- Hide role icons on raid frame
        if self.db.hideRole then
			DefaultCompactUnitFrameOptions.displayRoleIcon = false
		end		

		if self.db.hideRoleParty then
			DefaultCompactUnitFrameOptions.displayRoleIcon = false		  
		end

        -- Hide Raid Manager Panel
		if self.db.hideRaidMan then
			local buildVersion = select(4,GetBuildInfo())
			if buildVersion >= 100000 then -- Dragonflight or later
				CompactRaidFrameManager:UnregisterAllEvents()
				CompactRaidFrameManager:HookScript("OnShow", function(s) s:Hide() end)
				CompactRaidFrameManager:Hide()
			elseif buildVersion < 39999 then -- Classic
				CompactRaidFrameContainer:SetParent(UIParent)
				CompactRaidFrameManager:UnregisterAllEvents()
				CompactRaidFrameManager:HookScript("OnShow", function(s) s:Hide() end)
				CompactRaidFrameManager:Hide()
			end
		end
		

        -- Replace enemy player names with numbers on arena namplates
        if self.db.hideNameArena then
            local U=UnitIsUnit hooksecurefunc("CompactUnitFrame_UpdateName",function(F)if IsActiveBattlefieldArena()and F.unit:find("nameplate")then for i=1,5 do if U(F.unit,"arena"..i)then F.name:SetText(i)F.name:SetTextColor(1,0,0)break end end end end)
        end

		if self.db.hideNameArenaFriendly then
            local U=UnitIsUnit hooksecurefunc("CompactUnitFrame_UpdateName",function(F)if IsActiveBattlefieldArena()and F.unit:find("nameplate")then for i=1,5 do if U(F.unit,"party"..i)then F.name:SetText(i)F.name:SetTextColor(0,1,0)break end end end end)
        end
    end
end

f:RegisterEvent("ADDON_LOADED")
f:SetScript("OnEvent", f.OnEvent)

function f:InitializeOptions()
	self.panel = CreateFrame("Frame")
	self.panel.name = "Hide Realm Names"

	local title = self.panel:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
	title:SetPoint("TOPLEFT", 16, -16)
	title:SetText(self.panel.name)

	local subtitle = self.panel:CreateFontString(nil, 'ARTWORK', 'GameFontNormal')
	subtitle:SetJustifyH('LEFT')
	subtitle:SetPoint('TOPLEFT', title, 'BOTTOMLEFT', 0, -8)
	subtitle:SetPoint('RIGHT', -32, 0)
	subtitle:SetText('All changes will take effect after a UI reload.')

	local subheader_1 = self.panel:CreateFontString(nil, 'ARTWORK', 'GameFontNormalLarge')
	subheader_1:SetJustifyH('LEFT')
	subheader_1:SetPoint('TOPLEFT', subtitle, 'BOTTOMLEFT', 0, -40)
	subheader_1:SetPoint('RIGHT', -32, 0)
	subheader_1:SetText('Group Frame Options')

	local subheader_realm = self.panel:CreateFontString(nil, 'ARTWORK', 'GameFontHighlight')
	subheader_realm:SetJustifyH('LEFT')
	subheader_realm:SetPoint('TOPLEFT', subheader_1, 'BOTTOMLEFT', 0, -10)
	subheader_realm:SetPoint('RIGHT', -32, 0)
	subheader_realm:SetText('Hide Realm Names')
    
    local cb_hide_realms = CreateFrame("CheckButton", nil, self.panel, "InterfaceOptionsCheckButtonTemplate")
	cb_hide_realms:SetPoint("TOPLEFT", subheader_realm, 0, -15)
	cb_hide_realms.Text:SetText("Raid")
	cb_hide_realms:HookScript("OnClick", function(_, btn, down)
		self.db.hideRealm = cb_hide_realms:GetChecked()
	end)
	cb_hide_realms:SetChecked(self.db.hideRealm)

	local cb_hide_realms_party = CreateFrame("CheckButton", nil, self.panel, "InterfaceOptionsCheckButtonTemplate")
	cb_hide_realms_party:SetPoint("TOPLEFT", cb_hide_realms, 60, 0)
	cb_hide_realms_party.Text:SetText("Party")
	cb_hide_realms_party:HookScript("OnClick", function(_, btn, down)
		self.db.hideRealmParty = cb_hide_realms_party:GetChecked()
	end)
	cb_hide_realms_party:SetChecked(self.db.hideRealmParty)

	local subheader_names = self.panel:CreateFontString(nil, 'ARTWORK', 'GameFontHighlight')
	subheader_names:SetJustifyH('LEFT')
	subheader_names:SetPoint('TOPLEFT', cb_hide_realms, 'BOTTOMLEFT', 0, -20)
	subheader_names:SetPoint('RIGHT', -32, 0)
	subheader_names:SetText('Hide Player Names')

	local cb_hide_names = CreateFrame("CheckButton", nil, self.panel, "InterfaceOptionsCheckButtonTemplate")
	cb_hide_names:SetPoint("TOPLEFT", subheader_names, 0, -15)
	cb_hide_names.Text:SetText("Raid")
	cb_hide_names:HookScript("OnClick", function(_, btn, down)
		self.db.hideName = cb_hide_names:GetChecked()
	end)
	cb_hide_names:SetChecked(self.db.hideName)

	local cb_hide_names_party = CreateFrame("CheckButton", nil, self.panel, "InterfaceOptionsCheckButtonTemplate")
	cb_hide_names_party:SetPoint("TOPLEFT", cb_hide_names, 60, 0)
	cb_hide_names_party.Text:SetText("Party")
	cb_hide_names_party:HookScript("OnClick", function(_, btn, down)
		self.db.hideNameParty = cb_hide_names_party:GetChecked()
	end)
	cb_hide_names_party:SetChecked(self.db.hideNameParty)

	local subheader_roles = self.panel:CreateFontString(nil, 'ARTWORK', 'GameFontHighlight')
	subheader_roles:SetJustifyH('LEFT')
	subheader_roles:SetPoint('TOPLEFT', subheader_realm, 'TOPLEFT', 200, 0)
	subheader_roles:SetPoint('RIGHT', 0, 0)
	subheader_roles:SetText('Hide Role Icons')

    local cb_hide_roles = CreateFrame("CheckButton", nil, self.panel, "InterfaceOptionsCheckButtonTemplate")
	cb_hide_roles:SetPoint("TOPLEFT", subheader_roles, 0, -15)
	cb_hide_roles.Text:SetText("Raid")
	cb_hide_roles:HookScript("OnClick", function(_, btn, down)
		self.db.hideRole = cb_hide_roles:GetChecked()
	end)
	cb_hide_roles:SetChecked(self.db.hideRole)

	local cb_hide_roles_party = CreateFrame("CheckButton", nil, self.panel, "InterfaceOptionsCheckButtonTemplate")
	cb_hide_roles_party:SetPoint("TOPLEFT", cb_hide_roles, 60, 0)
	cb_hide_roles_party.Text:SetText("Party")
	cb_hide_roles_party:HookScript("OnClick", function(_, btn, down)
		self.db.hideRoleParty = cb_hide_roles_party:GetChecked()
	end)
	cb_hide_roles_party:SetChecked(self.db.hideRoleParty)

	local subheader_raidman = self.panel:CreateFontString(nil, 'ARTWORK', 'GameFontHighlight')
	subheader_raidman:SetJustifyH('LEFT')
	subheader_raidman:SetPoint('TOPLEFT', subheader_names, 'TOPLEFT', 200, 0)
	subheader_raidman:SetPoint('RIGHT', 0, 0)
	subheader_raidman:SetText('Raid Frame Manager (left side panel)')

	local cb_hide_raidman = CreateFrame("CheckButton", nil, self.panel, "InterfaceOptionsCheckButtonTemplate")
	cb_hide_raidman:SetPoint("TOPLEFT", subheader_raidman, 0, -15)
	cb_hide_raidman.Text:SetText("Hidden")
	cb_hide_raidman:HookScript("OnClick", function(_, btn, down)
		self.db.hideRaidMan = cb_hide_raidman:GetChecked()
	end)
	cb_hide_raidman:SetChecked(self.db.hideRaidMan)

	local subheader_2 = self.panel:CreateFontString(nil, 'ARTWORK', 'GameFontNormalLarge')
	subheader_2:SetJustifyH('LEFT')
	subheader_2:SetPoint('TOPLEFT', subheader_1, 'BOTTOMLEFT', 0, -180)
	subheader_2:SetPoint('RIGHT', -32, 0)
	subheader_2:SetText('Nameplate Options')

	local subheader_nameplate = self.panel:CreateFontString(nil, 'ARTWORK', 'GameFontHighlight')
	subheader_nameplate:SetJustifyH('LEFT')
	subheader_nameplate:SetPoint('TOPLEFT', subheader_2, 'BOTTOMLEFT', 0, -10)
	subheader_nameplate:SetPoint('RIGHT', 0, 0)
	subheader_nameplate:SetText('Hide Realm (outside instances only)')

	local cb_hide_realms_np = CreateFrame("CheckButton", nil, self.panel, "InterfaceOptionsCheckButtonTemplate")
	cb_hide_realms_np:SetPoint("TOPLEFT", subheader_nameplate, 0, -15)
	cb_hide_realms_np.Text:SetText("Enabled")
	cb_hide_realms_np:HookScript("OnClick", function(_, btn, down)
		self.db.hideRealmNP = cb_hide_realms_np:GetChecked()
	end)
	cb_hide_realms_np:SetChecked(self.db.hideRealmNP)

	local subheader_arena_name = self.panel:CreateFontString(nil, 'ARTWORK', 'GameFontHighlight')
	subheader_arena_name:SetJustifyH('LEFT')
	subheader_arena_name:SetPoint('TOPLEFT', cb_hide_realms_np, 'TOPLEFT', 0, -40)
	subheader_arena_name:SetPoint('RIGHT', 0, 0)
	subheader_arena_name:SetText('Replace Names with Numbers on Arena Nameplates (Arena 123)')

	local cb_hide_arena = CreateFrame("CheckButton", nil, self.panel, "InterfaceOptionsCheckButtonTemplate")
	cb_hide_arena:SetPoint("TOPLEFT", subheader_arena_name, 0, -15)
	cb_hide_arena.Text:SetText("Enemy")
	cb_hide_arena:HookScript("OnClick", function(_, btn, down)
		self.db.hideNameArena = cb_hide_arena:GetChecked()
	end)
	cb_hide_arena:SetChecked(self.db.hideNameArena)

	local cb_hide_arena_friendly = CreateFrame("CheckButton", nil, self.panel, "InterfaceOptionsCheckButtonTemplate")
	cb_hide_arena_friendly:SetPoint("TOPLEFT", cb_hide_arena, 65, 0)
	cb_hide_arena_friendly.Text:SetText("Friendly")
	cb_hide_arena_friendly:HookScript("OnClick", function(_, btn, down)
		self.db.hideNameArenaFriendly = cb_hide_arena_friendly:GetChecked()
	end)
	cb_hide_arena_friendly:SetChecked(self.db.hideNameArenaFriendly)

	local btn = CreateFrame("Button", nil, self.panel, "UIPanelButtonTemplate")
	btn:SetPoint("TOPLEFT", cb_hide_arena, 0, -50)
	btn:SetText("Save and Reload")
	btn:SetWidth(126)
	btn:SetScript("OnClick", function()
        ReloadUI();
	end)

	InterfaceOptions_AddCategory(self.panel)
end

SLASH_HRN1 = "/hrn"
SLASH_HRN2 = "/hiderealmnames"

SlashCmdList.HRN = function(msg, editBox)
	InterfaceOptionsFrame_OpenToCategory(f.panel)
end